@@ -1,5 +1,5 @@
 /************************************************************************
- * Copyright (C) 2005-2009 Philipp Marek.
+ * Copyright (C) 2005-2009,2015 Philipp Marek.
  *
  * This program is free software;  you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -84,7 +84,7 @@ ex:
  * \note If there's an irreparable conversion error, we must not print 
  * (parts of) the strings. One or even both might not be suitable for 
  * printing on the current console - so we do not know what could happen. */
-inline int hlp___do_convert(iconv_t cd, 
+static inline int hlp___do_convert(iconv_t cd, 
 		const char* from, char** to, 
 		int len)
 {
@@ -404,6 +404,42 @@ int hlp__fstat(int fd, struct sstat_t *st)
 /** @} */
 
 
+static const char *src;
+static const char *src_1, *src_2, *src_3;
+static int eop;
+static va_list va;
+static const char null=0;
+static int status;
+void Increment()
+{
+	src  =src_1;
+	src_1=src_2;
+	src_2=src_3;
+
+	/* Next character. */
+	if (*src_3) src_3++;
+
+	/* If just prepared character in \c *src_3 is a \c \\0 , 
+	 * wrap to next argument. 
+	 * (If there are still arguments.) */
+	if (!eop)
+		while (!*src_3)
+		{
+			src_3=va_arg(va, char*);
+			if (src_3) 
+				DEBUGP("adding %s", src_3);
+			else
+			{ 
+				/* End of parameters. Let the pointers point to a valid character
+				 * (instead of NULL), so that dereferencing works. */
+				eop=1;
+				src_3=&null;
+				break;
+			}
+		}
+}
+
+
 /** -.
  * \param dst A target buffer
  * \param len An optional length-saving field
@@ -440,11 +476,6 @@ char *hlp__pathcopy(char *dst, int *len, ...)
 	static const char ps[]={ PATH_SEPARATOR, 0 };
 	int had_path;
 	char *dest;
-	const char *src;
-	const char *src_1, *src_2, *src_3;
-	int status, eop;
-	va_list va;
-	static const char null=0;
 
 
 	status=0;
@@ -456,35 +487,6 @@ char *hlp__pathcopy(char *dst, int *len, ...)
 	src_1=src_2=src_3=&null;
 
 
-	void Increment()
-	{
-		src  =src_1;
-		src_1=src_2;
-		src_2=src_3;
-
-		/* Next character. */
-		if (*src_3) src_3++;
-
-		/* If just prepared character in \c *src_3 is a \c \\0 , 
-		 * wrap to next argument. 
-		 * (If there are still arguments.) */
-		if (!eop)
-			while (!*src_3)
-			{
-				src_3=va_arg(va, char*);
-				if (src_3) 
-					DEBUGP("adding %s", src_3);
-				else
-				{ 
-					/* End of parameters. Let the pointers point to a valid character
-					 * (instead of NULL), so that dereferencing works. */
-					eop=1;
-					src_3=&null;
-					break;
-				}
-			}
-	}
-
 
 	/* Do first 4 characters */
 	Increment();
@@ -1269,6 +1271,9 @@ void hlp___encode_filter_child(int pipe_in[2], int pipe_out[2],
 	STOPIF_CODE_ERR(!WIFEXITED(i), ECANCELED,
 			"The command '%s' didn't exit normally", command);
 
+	/* Silence compiler warning. */
+	(void) status;
+
 	/* Don't do parent cleanups, just quit. */
 	_exit(0);
 ex:
@@ -1307,8 +1312,6 @@ int hlp__encode_filter(svn_stream_t *s_stream, const char *command,
 
 
 	DEBUGP("encode filter: %s", command);
-	status=0;
-
 	STOPIF( hlp__alloc( &encoder, sizeof(*encoder)), NULL);
 
 	new_str=svn_stream_create(encoder, pool);
@@ -1580,6 +1583,7 @@ int hlp__format_path(struct estat *sts, char *wc_relative_path,
 
 
 	status=0;
+	path=NULL;
 	switch (opt__get_int(OPT__PATH))
 	{
 		case PATH_WCRELATIVE:
@@ -1956,7 +1960,7 @@ ex:
 /** -.
  * If \a source is not \c NULL \a len bytes are copied.
  * The buffer is \b always \c \\0 terminated. */
-int hlp__strnalloc(int len, char **dest, const char const *source)
+int hlp__strnalloc(int len, char **dest, const char * const source)
 {
 	int status;
 
@@ -1972,7 +1976,7 @@ ex:
 
 /** -. */
 int hlp__strmnalloc(int len, char **dest, 
-		const char const *source, ...)
+		const char * source, ...)
 {
 	int status;
 	va_list vl;
